@@ -26,7 +26,10 @@ MODAIC_REPO_PATH = "farouk1/nanocode"
 
 def format_auth_error(err: Exception) -> str | None:
     message = str(err)
-    if "OpenrouterException" in message and "No cookie auth credentials found" in message:
+    if (
+        "OpenrouterException" in message
+        and "No cookie auth credentials found" in message
+    ):
         return (
             "OpenRouter authentication failed: no credentials found. "
             "Set `OPENROUTER_API_KEY` or run `/openrouter-key` to cache it."
@@ -46,9 +49,13 @@ def main():
         print(f"{GREEN}⏺ Loaded OpenRouter key from cache{RESET}")
 
     model, sub_lm = resolve_startup_models()
-    print(f"Using env: {os.getenv('MODAIC_ENV', 'prod')}")
+    if os.getenv("MODAIC_ENV"):
+        print(f"Using env: {os.getenv('MODAIC_ENV', 'prod')}")
+
     agent = AutoProgram.from_precompiled(
-        MODAIC_REPO_PATH, rev=os.getenv("MODAIC_ENV", "prod"), config={"lm": model, "sub_lm": sub_lm}
+        MODAIC_REPO_PATH,
+        rev=os.getenv("MODAIC_ENV", "prod"),
+        config={"lm": model, "sub_lm": sub_lm},
     )
 
     print(
@@ -57,7 +64,7 @@ def main():
 
     history = []
 
-    mcp_servers = {} # mcp registry
+    mcp_servers = {}  # mcp registry
 
     while True:
         try:
@@ -79,7 +86,7 @@ def main():
 
             if not user_input:
                 continue
-            
+
             if user_input in ("/q", "exit"):
                 break
 
@@ -93,9 +100,13 @@ def main():
                     print(f"{GREEN}⏺ OpenRouter key cleared{RESET}")
                     continue
 
-                key = args[0] if args else getpass.getpass(
-                    f"{BOLD}{BLUE}❯{RESET} Enter OpenRouter API key (input hidden): "
-                ).strip()
+                key = (
+                    args[0]
+                    if args
+                    else getpass.getpass(
+                        f"{BOLD}{BLUE}❯{RESET} Enter OpenRouter API key (input hidden): "
+                    ).strip()
+                )
 
                 if not key:
                     print(f"{RED}⏺ OpenRouter key not set (empty input){RESET}")
